CREATE OR REPLACE PACKAGE BODY xmldoc AS

  FUNCTION get(name VARCHAR2, createNew BOOLEAN) RETURN CLOB IS
    c               CLOB;
    create_new_clob EXCEPTION;
  BEGIN
    IF createNew THEN
      remove(name);
      RAISE create_new_clob;
    END IF;

    SELECT xmldoc INTO c FROM xml_documents WHERE docname = name;
    RETURN c;

  EXCEPTION
    WHEN NO_DATA_FOUND OR create_new_clob THEN
      IF createNew THEN
        INSERT INTO xml_documents(docname,xmldoc)
             VALUES(name,empty_clob())
        RETURNING xmldoc INTO c;
        RETURN c;
      ELSE
        RETURN NULL;
      END IF;
  END;

  FUNCTION getAsCLOB(name VARCHAR2) RETURN CLOB IS
  BEGIN
    RETURN get(name,FALSE);
  END;

  FUNCTION  getAsText(name VARCHAR2) RETURN VARCHAR2 IS
  BEGIN
    RETURN dbms_lob.substr(getAsCLOB(name));
  END;

  FUNCTION  get(name VARCHAR2) RETURN xmldom.DOMDocument IS
  BEGIN
    RETURN xml.parse(getAsCLOB(name));
  END;

  PROCEDURE save(name VARCHAR2,xmldoc VARCHAR2,docommit BOOLEAN:=TRUE) IS
    c CLOB := get(name, createNew=>TRUE);
    doc xmldom.DOMDocument;
  BEGIN
    doc := xml.parse(xmldoc);
    xmldom.writeToClob(doc,c);
    xml.freeDocument(doc);
    IF docommit THEN commit; END IF;
  EXCEPTION
    WHEN OTHERS THEN xml.freeDocument(doc); RAISE;
  END;

  PROCEDURE save(name VARCHAR2,xmldoc CLOB,docommit BOOLEAN:=TRUE) IS
    c CLOB := get(name, createNew=>TRUE);
    doc xmldom.DOMDocument;
  BEGIN
    doc := xml.parse(xmldoc);
    xmldom.writeToClob(doc,c);
    xml.freeDocument(doc);
    IF docommit THEN commit; END IF;
  EXCEPTION
    WHEN OTHERS THEN xml.freeDocument(doc); RAISE;
  END;

  PROCEDURE save(name VARCHAR2,xmldoc BFILE,docommit BOOLEAN:=TRUE) IS
    c CLOB := get(name, createNew=>TRUE);
    doc xmldom.DOMDocument;
  BEGIN
    doc := xml.parse(xmldoc);
    xmldom.writeToClob(doc,c);
    xml.freeDocument(doc);
    IF docommit THEN commit; END IF;
  EXCEPTION
    WHEN OTHERS THEN xml.freeDocument(doc); RAISE;
  END;

  PROCEDURE save(name VARCHAR2,xmldoc xmldom.DOMDocument,docommit BOOLEAN:=TRUE) IS
    c CLOB := get(name, createNew=>TRUE);
  BEGIN
    xmldom.writeToClob(xmldoc,c);
    IF docommit THEN commit; END IF;
  END;

  PROCEDURE remove(name VARCHAR2,docommit BOOLEAN := TRUE) IS
    c CLOB := get(name, createNew=>FALSE);
  BEGIN
    DELETE FROM xml_documents WHERE docname = name;
    IF docommit THEN commit; END IF;
  END;

  FUNCTION  docExists(name VARCHAR2) RETURN BOOLEAN IS
  BEGIN
    RETURN getAsCLOB(name) IS NOT NULL;
  END;
END;
