<!--
 | Examples.xsl - Output HTML for examples in Building Oracle XML Applications
 |
 | * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 | NOTE: This stylesheet requires Oracle XML Parser V2 Release 2.0.2.10
 | ~~~~  or greater to function properly.
 | * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 |
 | This stylesheet uses <ora:output> to produce multiple output documents
 | This single stylesheet transforms the Examples.xml document to
 | produces the following files:
 |
 |  ../Examples/index.html                 - overall table of contents
 |  ../Examples/chXX/index-chXX.html       - per-chapter, table of contents
 |  ../Examples/chXX/htmlpreview/YYYY.html - HTML preview of each example
 |  ../Examples/chXX/chapter-setup.html    - per-chapter Info on database setup
 +-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:ora="http://www.oracle.com/XSL/Transform/java"
   xmlns:file="http://www.oracle.com/XSL/Transform/java/TextUtils"
   extension-element-prefixes="ora"
   exclude-result-prefixes="file ora">

  <xsl:output method="text"/>
  <ora:output name="x" indent="no" method="html"/>
  <xsl:template match="/">
    <!-- Build the table of contents and setup info pages -->
    <xsl:apply-templates select="examples" mode="toc"/>
    <!-- Build the page for each chapter and format each example -->
    <xsl:apply-templates select="examples"/>
  </xsl:template>

  <xsl:template match="examples" mode="toc">
    <ora:output href="../Examples/index.html" use="x" method="html">
      <html>
        <head>
          <title>Building Oracle XML Applications Examples</title>
          <link rel="StyleSheet" href="../ReadMe/ReadMe.css" />
        </head>
        <body>
          <h1>
            <a style="text-decoration:none" href="http://www.oreilly.com/catalog/orxmlapp"><img border="0" valign="absmiddle" src="../ReadMe/oreilly.gif"/>Building Oracle XML Applications</a> Examples
          </h1>
          <table border="0" width="100%" cellpadding="0" cellspacing="0">
            <tr>
              <td width="100%">
                <table width="100%" border="0" cellpadding="5" cellspacing="0">
                  <tr class="tableheader">
                    <th width="10%" align="right">Chapter</th>
                    <th width="50%" align="left">Title</th>
                    <th width="40%" align="left">Setup Information</th>
                  </tr>
                </table>
                <table cellpadding="0" cellspacing="0" width="100%" class="box">
                  <tr>
                    <td>
                      <table width="100%" border="0" cellpadding="5" cellspacing="0">
                        <xsl:apply-templates select="chapter" mode="toc"/>
                      </table>
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
          </table>
          <span style="font-size: 8pt">
            <xsl:text>Version </xsl:text>
            <xsl:value-of select="@version"/>
            <xsl:text>, last updated </xsl:text>
            <xsl:value-of select="@last-updated"/>
          </span>
        </body>
      </html>
    </ora:output>
  </xsl:template>

  <xsl:template match="examples">
    <xsl:apply-templates select="chapter"/>
  </xsl:template>

  <xsl:template match="chapter">
    <ora:output href="../Examples/{@id}/index-{@id}.html" use="x" method="html">
      <html>
        <head>
          <title>
            <xsl:text>Examples for Chapter </xsl:text>
            <xsl:value-of select="format-number(
                                    number(substring-after(@id,'ch')),'0')"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="@name"/>
          </title>
          <link rel="StyleSheet" href="../../ReadMe/ReadMe.css" />
        </head>
        <body>
          <h1>
            Chapter <xsl:value-of select="format-number(
                                    number(substring-after(@id,'ch')),'0')"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="@name"/>
          </h1>
          <table border="0" width="100%" cellpadding="0" cellspacing="0">
            <tr>
              <td width="100%">
                <table width="100%" border="0" cellpadding="5" cellspacing="0">
                  <tr class="tableheader">
                    <th width="10%" align="right">Example</th>
                    <th width="50%" align="left">Caption</th>
                    <th width="40%" align="left">Filename</th>
                  </tr>
                </table>
                <table cellpadding="0" cellspacing="0" width="100%" class="box">
                  <tr>
                    <td>
                      <table width="100%" border="0" cellpadding="5" cellspacing="0">
                        <xsl:if test="not(example)">
                          <tr>
                            <td align="center" colspan="3">
                              <i>No example files for this chapter.</i>
                            </td>
                          </tr>
                        </xsl:if>
                        <xsl:apply-templates select="example"/>
                      </table>
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
          </table>
        </body>
      </html>
    </ora:output>
  </xsl:template>

  <xsl:template match="example">
    <tr class="r{position() mod 2}">
      <td width="10%" align="right">
        <xsl:value-of select="concat(
                                number(substring-before(@id,'-')),
                                substring(@id,3))"/>
      </td>
      <td width="50%">
        <xsl:value-of select="caption"/>
      </td>
      <td width="40%" class="literal">
        <a href="htmlpreview/{substring-after(@file,'/')}.html">
          <xsl:value-of select="substring-after(@file,'/')"/>
        </a>
      </td>
    </tr>
    <!-- Create the HTML Preview page for each example file -->
    <xsl:call-template name="genPreviewPageForCurrentExample"/>
  </xsl:template>

  <xsl:template name="genPreviewPageForCurrentExample">
    <ora:output method="html" use="x"
      href="htmlpreview/{substring-after(@file,'/')}.html">
      <html>
        <head>
          <title>
            <xsl:text>Example </xsl:text>
            <xsl:value-of select="concat(
                                    number(substring-before(@id,'-')),
                                    substring(@id,3))"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="@name"/>
          </title>
          <link rel="StyleSheet" href="../../../ReadMe/ReadMe.css" />
        </head>
        <body>
          <h3>
            <xsl:text>Example </xsl:text>
            <xsl:value-of select="concat(
                                    number(substring-before(@id,'-')),
                                    substring(@id,3))"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="caption"/>
          </h3>
          <table cellspacing="10" class="box">
            <tr>
              <td>
                <pre>
                  <xsl:variable name="file"
                                select="concat('E:\orxmlapp\Examples\',
                                               ../@id,
                                               '\',
                                               substring-after(@file,'/'))"/>
                  <xsl:value-of select="file:contents($file)"/>
                </pre>
              </td>
            </tr>
          </table>
        </body>
      </html>
    </ora:output>
  </xsl:template>

  <xsl:template match="chapter" mode="toc">
    <tr class="r{position() mod 2}">
      <td width="10%" align="right">
        <xsl:value-of select="number(substring-after(@id,'ch'))"/>
      </td>
      <td width="50%">
        <a href="{@id}/index-{@id}.html">
          <xsl:value-of select="@name"/>
        </a>
      </td>
      <td width="40%">
          <xsl:variable name="setup-info-available"
                       select="database-setup or external-libraries"/>
          <xsl:if test="$setup-info-available">
            <a href="{@id}/chapter-setup.html">
              <xsl:text>Chapter </xsl:text>
              <xsl:value-of select="number(substring-after(@id,'ch'))"/>
              <xsl:text> Setup Instructions</xsl:text>
            </a>
            <xsl:apply-templates select="." mode="chapter-setup"/>
          </xsl:if>
          <xsl:if test="not($setup-info-available)">&#160;</xsl:if>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="chapter" mode="chapter-setup">
    <ora:output method="html" use="x" href="{@id}/chapter-setup.html">
      <html>
        <head>
          <title>
            <xsl:text>Setup Instructions for Chapter </xsl:text>
            <xsl:value-of select="format-number(
                                    number(substring-after(@id,'ch')),'0')"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="@name"/>
          </title>
          <link rel="StyleSheet" href="../../ReadMe/ReadMe.css" />
        </head>
        <body>
          <h1>
            <xsl:text>Setup Instructions for Chapter </xsl:text>
            <xsl:value-of select="format-number(
                                    number(substring-after(@id,'ch')),'0')"/>
          </h1>
          <xsl:if test="database-setup">
            <h3><u>Database Setup</u></h3>
            <p>
              <xsl:text>Before running the examples in Chapter </xsl:text>
              <xsl:value-of select="format-number(
                                      number(substring-after(@id,'ch')),'0')"/>
              <xsl:text>, do the following:</xsl:text>
            </p>
            <ol>
              <li>
                <xsl:text>Set your current directory to </xsl:text>
                <b class="literal">
                  <xsl:text>./orxmlapp/Examples/</xsl:text>
                  <xsl:value-of select="@id"/>
                </b>
              </li>
              <li>
                <xsl:text>Run the following SQL scripts as the indicated user...</xsl:text>
                <p>
                  <ul type="disc">
                    <xsl:for-each select="database-setup/script">
                      <li>
                        <xsl:choose>
                          	<xsl:when test="@prev">
                              <xsl:text>If you have not already run it as part of the setup for Chapter </xsl:text>
                              <xsl:value-of select="number(substring-after(@prev,'ch'))"/>
                              <xsl:text>, then as</xsl:text> 
                            </xsl:when>
                            <xsl:otherwise>
                              <xsl:text>As</xsl:text>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:text> user </xsl:text>
                        <b class="literal">
                          <xsl:value-of select="@run-as"/>
                        </b>
                        <xsl:text>, run the </xsl:text>
                        <b class="literal">
                          <xsl:value-of select="@name"/>
                        </b>
                        <xsl:text> script.</xsl:text>
                        <xsl:variable name="explanation" select="normalize-space(.)"/>
                        <xsl:if test="$explanation!=''">
                          <br/><br/>
                          <xsl:apply-templates select="."/><br/><br/>
                        </xsl:if>
                      </li>
                    </xsl:for-each>
                  </ul>
                </p>
              </li>
            </ol>
            <p>
              To run a script use the SQL*Plus command-line tool that
              comes with your Oracle database using the command:
            </p>
            <span class="literal">$&#160;&#160;sqlplus&#160;&#160;<i>username</i>/<i>password</i>&#160;&#160;@<i>scriptname.sql</i></span>
          </xsl:if>
          <xsl:if test="external-libraries">
            <h3><u>Setup for External Java Libraries</u></h3>
            <p>
              <xsl:text>Before running the examples in Chapter </xsl:text>
              <xsl:value-of select="format-number(
                                      number(substring-after(@id,'ch')),'0')"/>
              <xsl:text>, do the following:</xsl:text>
            </p>
            <ol>
              <xsl:for-each select="external-libraries/library">
                <li>
                  <xsl:choose>
                    <xsl:when test="@prev">
                      <xsl:text>If you have not already created this library as part of the setup for Chapter </xsl:text>
                      <xsl:value-of select="number(substring-after(@prev,'ch'))"/>
                      <xsl:text>, then obtain</xsl:text> 
                    </xsl:when>
                    <xsl:otherwise>
                      <xsl:text>Obtain</xsl:text>
                    </xsl:otherwise>
                  </xsl:choose>
                  <xsl:text> the </xsl:text>
                  <xsl:value-of select="name"/>
                  <xsl:text> library </xsl:text>
                  <xsl:choose>
                    <xsl:when test="download">
                      <xsl:text> from </xsl:text>
                      <a href="{download/@url}">
                        <xsl:value-of select="download/@url"/>
                      </a>
                    </xsl:when>
                    <xsl:when test="shipped-with-database">
                      <xsl:text> that is shipped with Oracle8i</xsl:text>
                    </xsl:when>
                  </xsl:choose>
                  <xsl:text>, create a JDeveloper library for the </xsl:text>
                  <b class="literal">
                    <xsl:copy-of select=".//archive"/>
                  </b>
                  <xsl:text> archive, and add this library to the </xsl:text>
                  <b>Chapter-<xsl:value-of
                    select="substring-after(ancestor::chapter/@id,'ch')"/></b>
                  <xsl:text> project's library list.</xsl:text><br/><br/>
                </li>
              </xsl:for-each>
            </ol>
            <p>
              For detailed instructions on creating a JDeveloper library to
              represent a Java archive, see the <b>Using JDeveloper with Oracle
              XDK Components</b> section of Chapter 4.
            </p>
          </xsl:if>
        </body>
      </html>
    </ora:output>
  </xsl:template>

</xsl:stylesheet>
